@@ -76,11 +76,11 @@ typedef struct {
  */
 struct _NMSettingWired {
     NMSetting parent;
-    /* In the past, this struct was public API. Preserve ABI! */
 };
 
 struct _NMSettingWiredClass {
     NMSettingClass parent;
+
     /* In the past, this struct was public API. Preserve ABI! */
     gpointer padding[4];
 };
@@ -995,6 +995,17 @@ compare_property(const NMSettInfoSetting *sett_info,
         ->compare_property(sett_info, property_idx, con_a, set_a, con_b, set_b, flags);
 }
 
+static GVariant *
+_override_autoneg_get(const NMSettInfoSetting *               sett_info,
+                      guint                                   property_idx,
+                      NMConnection *                          connection,
+                      NMSetting *                             setting,
+                      NMConnectionSerializationFlags          flags,
+                      const NMConnectionSerializationOptions *options)
+{
+    return g_variant_new_boolean(nm_setting_wired_get_auto_negotiate((NMSettingWired *) setting));
+}
+
 /*****************************************************************************/
 
 static void
@@ -1291,12 +1302,11 @@ nm_setting_wired_class_init(NMSettingWiredClass *klass)
      * description: The property is not saved by the plugin.
      * ---end---
      */
-    _nm_setting_property_define_string(properties_override,
-                                       obj_properties,
-                                       NM_SETTING_WIRED_PORT,
-                                       PROP_PORT,
-                                       NM_SETTING_PARAM_NONE,
-                                       nm_setting_wired_get_port);
+    obj_properties[PROP_PORT] = g_param_spec_string(NM_SETTING_WIRED_PORT,
+                                                    "",
+                                                    "",
+                                                    NULL,
+                                                    G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
     /**
      * NMSettingWired:speed:
@@ -1353,12 +1363,11 @@ nm_setting_wired_class_init(NMSettingWiredClass *klass)
      *    "duplex" parameter in the ETHOOL_OPTS variable.
      * ---end---
      */
-    _nm_setting_property_define_string(properties_override,
-                                       obj_properties,
-                                       NM_SETTING_WIRED_DUPLEX,
-                                       PROP_DUPLEX,
-                                       NM_SETTING_PARAM_NONE,
-                                       nm_setting_wired_get_duplex);
+    obj_properties[PROP_DUPLEX] = g_param_spec_string(NM_SETTING_WIRED_DUPLEX,
+                                                      "",
+                                                      "",
+                                                      NULL,
+                                                      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
     /**
      * NMSettingWired:auto-negotiate:
@@ -1380,14 +1389,16 @@ nm_setting_wired_class_init(NMSettingWiredClass *klass)
      *    "speed" and "duplex" parameters (skips link configuration).
      * ---end---
      */
-    _nm_setting_property_define_boolean(properties_override,
-                                        obj_properties,
-                                        NM_SETTING_WIRED_AUTO_NEGOTIATE,
-                                        PROP_AUTO_NEGOTIATE,
-                                        FALSE,
-                                        NM_SETTING_PARAM_NONE,
-                                        nm_setting_wired_get_auto_negotiate,
-                                        .to_dbus_data.including_default = TRUE);
+    obj_properties[PROP_AUTO_NEGOTIATE] =
+        g_param_spec_boolean(NM_SETTING_WIRED_AUTO_NEGOTIATE,
+                             "",
+                             "",
+                             FALSE,
+                             G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+    _nm_properties_override_gobj(properties_override,
+                                 obj_properties[PROP_AUTO_NEGOTIATE],
+                                 NM_SETT_INFO_PROPERT_TYPE(.dbus_type   = G_VARIANT_TYPE_BOOLEAN,
+                                                           .to_dbus_fcn = _override_autoneg_get, ));
 
     /**
      * NMSettingWired:mac-address:
@@ -1531,12 +1542,12 @@ nm_setting_wired_class_init(NMSettingWiredClass *klass)
      *   cloned-mac-address.
      * ---end---
      */
-    _nm_setting_property_define_string(properties_override,
-                                       obj_properties,
-                                       NM_SETTING_WIRED_GENERATE_MAC_ADDRESS_MASK,
-                                       PROP_GENERATE_MAC_ADDRESS_MASK,
-                                       NM_SETTING_PARAM_FUZZY_IGNORE,
-                                       nm_setting_wired_get_generate_mac_address_mask);
+    obj_properties[PROP_GENERATE_MAC_ADDRESS_MASK] = g_param_spec_string(
+        NM_SETTING_WIRED_GENERATE_MAC_ADDRESS_MASK,
+        "",
+        "",
+        NULL,
+        G_PARAM_READWRITE | NM_SETTING_PARAM_FUZZY_IGNORE | G_PARAM_STATIC_STRINGS);
 
     /**
      * NMSettingWired:mac-address-blacklist:
@@ -1627,12 +1638,12 @@ nm_setting_wired_class_init(NMSettingWiredClass *klass)
      * example: NETTYPE=qeth
      * ---end---
      */
-    _nm_setting_property_define_string(properties_override,
-                                       obj_properties,
-                                       NM_SETTING_WIRED_S390_NETTYPE,
-                                       PROP_S390_NETTYPE,
-                                       NM_SETTING_PARAM_INFERRABLE,
-                                       nm_setting_wired_get_s390_nettype);
+    obj_properties[PROP_S390_NETTYPE] = g_param_spec_string(
+        NM_SETTING_WIRED_S390_NETTYPE,
+        "",
+        "",
+        NULL,
+        G_PARAM_READWRITE | NM_SETTING_PARAM_INFERRABLE | G_PARAM_STATIC_STRINGS);
 
     /**
      * NMSettingWired:s390-options: (type GHashTable(utf8,utf8)):
@@ -1708,13 +1719,12 @@ nm_setting_wired_class_init(NMSettingWiredClass *klass)
      * example: ETHTOOL_OPTS="wol gs sopass 00:11:22:33:44:55"
      * ---end---
      */
-    _nm_setting_property_define_string(properties_override,
-                                       obj_properties,
-                                       NM_SETTING_WIRED_WAKE_ON_LAN_PASSWORD,
-                                       PROP_WAKE_ON_LAN_PASSWORD,
-                                       NM_SETTING_PARAM_NONE,
-                                       nm_setting_wired_get_wake_on_lan_password);
-
+    obj_properties[PROP_WAKE_ON_LAN_PASSWORD] =
+        g_param_spec_string(NM_SETTING_WIRED_WAKE_ON_LAN_PASSWORD,
+                            "",
+                            "",
+                            NULL,
+                            G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
     /**
      * NMSettingWired:accept-all-mac-addresses:
      *
