@@ -91,11 +91,11 @@ typedef struct {
  */
 struct _NMSettingWirelessSecurity {
     NMSetting parent;
-    /* In the past, this struct was public API. Preserve ABI! */
 };
 
 struct _NMSettingWirelessSecurityClass {
     NMSettingClass parent;
+
     /* In the past, this struct was public API. Preserve ABI! */
     gpointer padding[4];
 };
@@ -1924,10 +1924,11 @@ nm_setting_wireless_security_class_init(NMSettingWirelessSecurityClass *klass)
                           NM_TYPE_WEP_KEY_TYPE,
                           NM_WEP_KEY_TYPE_UNKNOWN,
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
-    _nm_properties_override_gobj(properties_override,
-                                 obj_properties[PROP_WEP_KEY_TYPE],
-                                 &nm_sett_info_propert_type_plain_u,
-                                 .to_dbus_data.gprop_to_dbus_fcn = wep_key_type_to_dbus, );
+    _nm_properties_override_gobj(
+        properties_override,
+        obj_properties[PROP_WEP_KEY_TYPE],
+        NM_SETT_INFO_PROPERT_TYPE(.dbus_type         = G_VARIANT_TYPE_UINT32,
+                                  .gprop_to_dbus_fcn = wep_key_type_to_dbus, ));
 
     /**
      * NMSettingWirelessSecurity:wps-method:
